
From: Michael Krufky <mkrufky@m1k.net>

Peter Missel:
- Add support for the SVideo input on the GDI Black Gold.

Mauro Carvalho Chehab:
- Linux/version.h removed. Replaced by linux/utsname.h

Michael Krufky:
- Added analog support for DViCO FusionHDTV5 Gold.

CC: Peter Missel <peter.missel@onlinehome.de>
Signed-off-by: Mauro Carvalho Chehab <mchehab@brturbo.com.br>
Signed-off-by: Michael Krufky <mkrufky@m1k.net>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 Documentation/video4linux/CARDLIST.cx88 |    1 +
 drivers/media/video/cx88/cx88-cards.c   |   28 ++++++++++++++++++++++++++++
 drivers/media/video/cx88/cx88.h         |    3 ++-
 3 files changed, 31 insertions(+), 1 deletion(-)

diff -puN Documentation/video4linux/CARDLIST.cx88~v4l-cx88-card-support-and-documentation-finishing Documentation/video4linux/CARDLIST.cx88
--- devel/Documentation/video4linux/CARDLIST.cx88~v4l-cx88-card-support-and-documentation-finishing	2005-07-29 23:06:27.000000000 -0700
+++ devel-akpm/Documentation/video4linux/CARDLIST.cx88	2005-07-29 23:06:27.000000000 -0700
@@ -29,3 +29,4 @@ card=27 - PixelView PlayTV Ultra Pro (St
 card=28 - DViCO FusionHDTV 3 Gold-T
 card=29 - ADS Tech Instant TV DVB-T PCI
 card=30 - TerraTec Cinergy 1400 DVB-T
+card=31 - DViCO FusionHDTV 5 Gold
diff -puN drivers/media/video/cx88/cx88-cards.c~v4l-cx88-card-support-and-documentation-finishing drivers/media/video/cx88/cx88-cards.c
--- devel/drivers/media/video/cx88/cx88-cards.c~v4l-cx88-card-support-and-documentation-finishing	2005-07-29 23:06:27.000000000 -0700
+++ devel-akpm/drivers/media/video/cx88/cx88-cards.c	2005-07-29 23:06:27.000000000 -0700
@@ -499,6 +499,9 @@ struct cx88_board cx88_boards[] = {
 		.input          = {{
                         .type   = CX88_VMUX_DVB,
                         .vmux   = 0,
+		},{
+			.type   = CX88_VMUX_SVIDEO,
+			.vmux   = 2,
                 }},
 		.dvb            = 1,
 	},
@@ -756,6 +759,27 @@ struct cx88_board cx88_boards[] = {
 		}},
 		.dvb            = 1,
 	},
+	[CX88_BOARD_DVICO_FUSIONHDTV_5_GOLD] = {
+		.name           = "DViCO FusionHDTV 5 Gold",
+		.tuner_type     = TUNER_LG_TDVS_H062F,
+		.radio_type     = UNSET,
+		.tuner_addr	= ADDR_UNSET,
+		.radio_addr	= ADDR_UNSET,
+		/*  See DViCO FusionHDTV 3 Gold-Q for GPIO documentation.  */
+		.input          = {{
+                        .type   = CX88_VMUX_TELEVISION,
+                        .vmux   = 0,
+                        .gpio0  = 0x0f0d,
+                },{
+                        .type   = CX88_VMUX_COMPOSITE1,
+                        .vmux   = 1,
+                        .gpio0  = 0x0f00,
+                },{
+                        .type   = CX88_VMUX_SVIDEO,
+                        .vmux   = 2,
+                        .gpio0  = 0x0f00,
+                }},
+	},
 };
 const unsigned int cx88_bcount = ARRAY_SIZE(cx88_boards);
 
@@ -883,6 +907,10 @@ struct cx88_subid cx88_subids[] = {
 		.subvendor = 0x153b,
 		.subdevice = 0x1166,
 		.card      = CX88_BOARD_TERRATEC_CINERGY_1400_DVB_T1,
+ 	},{
+		.subvendor = 0x18ac,
+		.subdevice = 0xd500,
+		.card      = CX88_BOARD_DVICO_FUSIONHDTV_5_GOLD,
 	},
 };
 const unsigned int cx88_idcount = ARRAY_SIZE(cx88_subids);
diff -puN drivers/media/video/cx88/cx88.h~v4l-cx88-card-support-and-documentation-finishing drivers/media/video/cx88/cx88.h
--- devel/drivers/media/video/cx88/cx88.h~v4l-cx88-card-support-and-documentation-finishing	2005-07-29 23:06:27.000000000 -0700
+++ devel-akpm/drivers/media/video/cx88/cx88.h	2005-07-29 23:06:27.000000000 -0700
@@ -1,5 +1,5 @@
 /*
- * $Id: cx88.h,v 1.69 2005/07/13 17:25:25 mchehab Exp $
+ * $Id: cx88.h,v 1.70 2005/07/24 17:44:09 mkrufky Exp $
  *
  * v4l2 device driver for cx2388x based TV cards
  *
@@ -171,6 +171,7 @@ extern struct sram_channel cx88_sram_cha
 #define CX88_BOARD_DVICO_FUSIONHDTV_3_GOLD_T  28
 #define CX88_BOARD_ADSTECH_DVB_T_PCI          29
 #define CX88_BOARD_TERRATEC_CINERGY_1400_DVB_T1  30
+#define CX88_BOARD_DVICO_FUSIONHDTV_5_GOLD 31
 
 enum cx88_itype {
 	CX88_VMUX_COMPOSITE1 = 1,
_
